# ListCataloguesResponse

Response object for a list of catalogues
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**catalogues** | [**list[Catalogue]**](Catalogue.md) | List of catalogues | [optional] [readonly] 
**limit** | **int** | Limit the number of catalogues included in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


